@@ -5,10 +5,11 @@ use strict;
 use warnings;
 
 # Modules.
-use Error::Pure::Print qw(err);
+use Error::Pure::PrintVar qw(err);
 
 # Error.
-err '1';
+err '1', '2', '3';
 
 # Output:
-# 1
\ No newline at end of file
+# 1
+# 2: 3
\ No newline at end of file
